'''
Created by auto_sdk on 2018.07.25
'''
from seven_top.top.api.base import RestApi
class FuwuPurchaseOrderConfirmRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.param_order_confirm_query_d_t_o = None

	def getapiname(self):
		return 'taobao.fuwu.purchase.order.confirm'



'''
Created by auto_sdk on 2020.11.30
'''
from seven_top.top.api.base import RestApi
class MiniappTemplateInstantiateRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.alias = None
		self.clients = None
		self.description = None
		self.ext_json = None
		self.icon = None
		self.name = None
		self.template_id = None
		self.template_version = None

	def getapiname(self):
		return 'taobao.miniapp.template.instantiate'



'''
Created by auto_sdk on 2018.12.22
'''
from seven_top.top.api.base import RestApi
class TmcGroupAddRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.group_name = None
		self.nicks = None
		self.user_platform = None

	def getapiname(self):
		return 'taobao.tmc.group.add'



'''
Created by auto_sdk on 2022.03.25
'''
from seven_top.top.api.base import RestApi
class SubusersSubaccountSearchRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.filter_key = None
		self.main_nick = None
		self.page_num = None
		self.page_size = None

	def getapiname(self):
		return 'taobao.subusers.subaccount.search'
